'''
        File:             import_train+test_data__example.py

        Description:      This Python script provides an example how to read & split the TRAIN and TEST datasets
                          of DOI http://dx.doi.org/10.24406/fordatis/236 for further processing.

        Author:           Tim Hauke Langer
        Affiliation:      Fraunhofer IIS/EAS (Dresden, Germany)
        Date:             07.12.2022
'''



import numpy as np
import random
from sklearn.utils import shuffle



def partition_data(dataset_path, train_filename, test_filename, seed_value=42):
    # 1. Load TRAIN+TEST data from *.NPY files
    train_data_labels = np.load(dataset_path + train_filename, allow_pickle=True).transpose()
    test_data_labels = np.load(dataset_path + test_filename, allow_pickle=True).transpose()

    # 2. Partition TRAIN+TEST data into actual data & labels
    train_data = train_data_labels[0]
    train_labels = train_data_labels[1]
    test_data = test_data_labels[0]
    test_labels = test_data_labels[1]

    # 3. shuffle TRAIN data before training a model
    random.seed(seed_value)
    np.random.seed(seed_value)
    train_data, train_labels = shuffle(train_data, train_labels)

    # 4. return separated TRAIN+TEST data & labels
    return train_data, train_labels, test_data, test_labels



if __name__ == "__main__":
    # TODO:   modify dataset path   (default assumption: *.NPY files are in same folder as this script)
    dataset_path = 'C:\\Users\\tlanger\\Desktop\\LZHighEnd_Datasets\\'
    train_filename = "small_segments_8000_train__good+bad.npy"
    test_filename = "small_segments_8000_test__good+bad.npy"

    train_data, train_labels, test_data, test_labels = partition_data(dataset_path=dataset_path,
                                                                      train_filename=train_filename,
                                                                      test_filename=test_filename,
                                                                      seed_value=42)

    print("\n\n[INFO]:\tTRAIN and TEST data loaded successfully!\n\n")
